@@ -2,6 +2,7 @@ import numpy as np
 import torch
 import torch.hub as hub
 import torch.nn as nn
+from IPython import get_ipython
 from torch import optim
 from torchvision import models
 
@@ -18,6 +19,11 @@ class ImageModelTraining:
         self.train_loader, self.val_loader = images_data.create_data_loaders(
             batch_size=self.image_model.batch_size)
         self.device = torch.device('cuda' if torch.cuda.is_available() else 'cpu')
+        print(f"Training using {self.device}")
+        if 'google.colab' in str(get_ipython()) and self.device == "cpu":
+            print(
+                f"If you are using Google Colab, you may want to change the runtime to use a GPU or TPU by "
+                f"selecting 'Runtime' -> 'Change runtime type'.")
         self.evaluate_predictions = None
 
     def get_model(self):
@@ -30,18 +36,18 @@ class ImageModelTraining:
         elif self.image_model.network_name == "EfficientNetB7":
             model = hub.load('rwightman/pytorch-image-models', 'efficientnet_b7', pretrained=True)
         elif self.image_model.network_name == "ResNet50":
-            model = models.resnet50(pretrained=True).to(self.device)
+            model = models.resnet50(pretrained=True)
         elif self.image_model.network_name == "ResNet101":
-            model = models.resnet101(pretrained=True).to(self.device)
+            model = models.resnet101(pretrained=True)
         elif self.image_model.network_name == "DenseNet121":
-            model = models.densenet121(pretrained=True).to(self.device)
+            model = models.densenet121(pretrained=True)
         else:
             raise ValueError(
                 f"Unsupported network name: {self.image_model.network_name}, please choose one of: {supported_models}")
         return model
 
     def load_model(self):
-        model = self.get_model()
+        model = self.get_model().to(self.device)
 
         # remove the specified number of layers from the top
         if self.image_model.remove_last_layers_num > 0:
@@ -92,6 +98,7 @@ class ImageModelTraining:
             inputs, labels = inputs.to(self.device), labels.to(self.device)
 
             try:
+                model = model.to(self.device)
                 outputs = model(inputs.float())
             except Exception as e:
                 print(f"Error while running model: {e}")
